@@ -1,13 +1,18 @@
-import queue
 import json
-from typing import Any
-from awsiot.greengrasscoreipc.model import UnauthorizedError, ComponentUpdatePolicyEvents
-from .IPC import IPC
-from .dev_IPC import dev_IPC
-import time as t
 import logging
-import traceback
 import os
+import queue
+import time as t
+import traceback
+from typing import Any
+
+from awsiot.greengrasscoreipc.model import (
+    ComponentUpdatePolicyEvents,
+    UnauthorizedError,
+)
+
+from .dev_IPC import dev_IPC
+from .IPC import IPC
 
 logger = logging.getLogger(__name__)
 
@@ -23,14 +28,16 @@ The IPC client V1 can't send new requests or process new event messages while th
 is blocked, this package is a wrapper to help the usage of Thread around IPC client v1
 """
 
-class IPCThreadSubscribe():
+
+class IPCThreadSubscribe:
     """
     Handle local IPC message reception through queue (IPCClientV1)
-    
+
         Args:
             sub_queue (Queue): The queue on which IPC local messages will arrive
             topics (list[str]): List of string containing the MQTT topics to listen for
     """
+
     def __init__(self, sub_queue: queue.Queue, topics: list[str] = []) -> None:
         self.sub_queue = sub_queue
 
@@ -38,14 +45,14 @@ class IPCThreadSubscribe():
             try:
                 IPC_client.subscribe(topic).set_handler(self.provider)
             except UnauthorizedError:
-                logging.info(f'Unauthorized to subscribe to topic {topic}')
+                logger.info(f"Unauthorized to subscribe to topic {topic}")
 
     def provider(self, message: Any, topic: str) -> None:
         """
         Callback function on message event
         """
         self.sub_queue.put({"message": message, "topic": topic})
-    
+
     def add_subscription(self, topic: str) -> bool:
         """
         Add a new MQTT topic to listen for
@@ -54,22 +61,23 @@ class IPCThreadSubscribe():
             IPC_client.subscribe(topic).set_handler(self.provider)
             return True
         except UnauthorizedError:
-            logging.info(f'Unauthorized to subscribe to topic {topic}')
+            logger.info(f"Unauthorized to subscribe to topic {topic}")
             return False
 
 
-class IPCThreadPublish():
+class IPCThreadPublish:
     """
     Handle local IPC message publication
 
         Args:
-            pub_queue (Queue): Listen for new MQTT messages to send. 
+            pub_queue (Queue): Listen for new MQTT messages to send.
             Any message on this Queue should be a dict with a key topic and message
     """
+
     def __init__(self, pub_queue: queue.Queue) -> None:
         self.pub_queue = pub_queue
         self.consumer()
-    
+
     def consumer(self):
         while True:
             data = self.pub_queue.get()
@@ -80,7 +88,7 @@ class IPCThreadPublish():
                     logger.exception("Can't publish message: [%s]", data)
 
 
-class IPCThreadPublishToCore():
+class IPCThreadPublishToCore:
     """
     Publish MQTT messages on IoT Core
 
@@ -88,6 +96,7 @@ class IPCThreadPublishToCore():
             pub_queue (Queue): Listen for new MQTT messages to send to IoT Core.
             Any message on this Queue should be a dict with a key topic and message
     """
+
     def __init__(self, pub_core_queue: queue.Queue) -> None:
         self.pub_core_queue = pub_core_queue
         self.consumer()
@@ -102,13 +111,14 @@ class IPCThreadPublishToCore():
                     t.sleep(0.5)
 
 
-class IPCThreadSubscribeToCore():
+class IPCThreadSubscribeToCore:
     """
     Subscribe to MQTT messages from IoT Core
 
         Args:
             sub_queue (Queue): The queue on which MQTT messages from IoT Core will arrive
     """
+
     def __init__(self, sub_queue: queue.Queue, topics: list) -> None:
         self.sub_queue = sub_queue
 
@@ -116,9 +126,9 @@ class IPCThreadSubscribeToCore():
             try:
                 IPC_client.subscribe_to_core(topic).set_handler(self.provider)
             except UnauthorizedError:
-                logging.info(f'Unauthorized to subscribe to topic {topic}')
+                logger.info(f"Unauthorized to subscribe to topic {topic}")
 
-    def provider(self, message: str, topic: str):
+    def provider(self, message: Any, topic: str):
         """
         Callback function on message event
         """
@@ -126,10 +136,10 @@ class IPCThreadSubscribeToCore():
             msg = json.loads(message)
             self.sub_queue.put({"message": msg, "topic": topic})
         except:
-            logging.info(f'Unable to parse data')
+            logger.info(f"Unable to parse data")
 
 
-class SubscribeComponentUpdate():
+class SubscribeComponentUpdate:
     """
     Handle deployment notification
 
@@ -137,28 +147,39 @@ class SubscribeComponentUpdate():
             updated_queue (Queue): This queue is used to inform a new update and success deployment
             flag_path (str): Path to check the flag to accept or delay the update
     """
+
     def __init__(self, updated_queue: queue.Queue, flag_path: str) -> None:
         self.updated_queue = updated_queue
         self.flag_path = flag_path
 
         try:
-            IPC_client.subscribe_to_component_update().set_handler(self.on_component_update)
+            IPC_client.subscribe_to_component_update().set_handler(
+                self.on_component_update
+            )
         except:
-            logging.info("Unable to subscribe to component update")
+            logger.info("Unable to subscribe to component update")
 
     def on_component_update(self, event: ComponentUpdatePolicyEvents) -> None:
         try:
             if event.pre_update_event is not None:
+
+                if not event.pre_update_event.deployment_id:
+                    logger.warning("Unkown deployment id")
+                    return
+
                 if os.path.exists(f"{self.flag_path}/AcceptedFlag"):
                     IPC_client.acknowledge_update(event.pre_update_event.deployment_id)
-                    logging.info(f'Acknowledged update for deployment {event.pre_update_event.deployment_id}')
+                    logger.info(
+                        f"Acknowledged update for deployment {event.pre_update_event.deployment_id}"
+                    )
                 else:
                     IPC_client.defer_update(event.pre_update_event.deployment_id)
-                    logging.info(f'Deferred update for deployment {event.pre_update_event.deployment_id}')
+                    logger.info(
+                        f"Deferred update for deployment {event.pre_update_event.deployment_id}"
+                    )
                     # Put the message in the queue to inform the system an update is needed
                     self.updated_queue.put({"request": event})
                     return
-
             elif event.post_update_event is not None:
                 try:
                     os.remove(f"{self.flag_path}/AcceptedFlag")
@@ -169,8 +190,10 @@ class SubscribeComponentUpdate():
                     os.remove(f"{self.flag_path}/UpdateFlag.txt")
                 except:
                     pass
-                
-                logging.info(f"Applied update for deployment {event.post_update_event.deployment_id}")
+
+                logger.info(
+                    f"Applied update for deployment {event.post_update_event.deployment_id}"
+                )
                 self.updated_queue.put({"applied": True})
         except:
             traceback.print_exc()
